@@ -17,8 +17,7 @@ check_layer_provider = function(layer, provider) {
       "You set layer = ",
       layer,
       " so you probably passed the provider to the layer argument!",
-      call. = FALSE,
-      immediate. = TRUE
+      call. = FALSE
     )
   }
   invisible(0)
@@ -28,7 +27,7 @@ check_layer_provider = function(layer, provider) {
 #'
 #' By default, the download directory is equal to `tempdir()`. You can set a
 #' persistent download directory by adding the following command to your
-#' `.Renviron` file (e.g. with `edit_r_environ` function in `usethis` package:
+#' `.Renviron` file (e.g. with `edit_r_environ` function in `usethis` package):
 #' `OSMEXT_DOWNLOAD_DIRECTORY=/path/to/osm/data`.
 #'
 #' @return A character vector representing the path for the download directory
@@ -38,10 +37,7 @@ check_layer_provider = function(layer, provider) {
 #' @examples
 #' oe_download_directory()
 oe_download_directory = function() {
-  download_directory = Sys.getenv("OSMEXT_DOWNLOAD_DIRECTORY", "")
-  if (download_directory == "") {
-    download_directory = tempdir()
-  }
+  download_directory = Sys.getenv("OSMEXT_DOWNLOAD_DIRECTORY", tempdir())
   if (!dir.exists(download_directory)) {
     dir.create(download_directory)
   }
